/*
 *
 Project name:
       UNI Hall Click
 Copyright:
      (c) mikroElektronika, 2014.
 Revision History:
      20140820:
      - Initial release (RD);
 Description:
      UUNI HALL click is a simple solution for adding an unipolar Hall switch to
      your design. It carries the Melexis US5881 unipolar Hall-effect switch and
      a 74LVC1T45 single bit, dual supply translating transceiver. UNI HALL click
      communicates with the target board through the mikroBUS INT line. The
      board is designed to use either a 3.3V or 5V power supply (which also defines the
      logic level of the output signal).
      The unipolar Hall effect sensor on UNI HALL click is sensitive to north pole magnetic
      fieldswhen exposed to such a field, it outputs a LOW logic level. Othewise the
      output is a HIGH logic level. In its simplest application, UNI HALL click
      can be employed as part of a long lasting contactless proximity switch.
      However, magnets can be employed in various ways to infer the speed,
      position, or other properties of an object; there are countless ways to utilize
      UNI HALL click in your design.

 * Test configuration:
     MCU:             STM32F107VC
                      http://www.st.com/st-web-ui/static/active/en/resource/technical/document/reference_manual/CD00171190.pdf
     Dev. Board:      EasyMx PRO v7 for STM32
                      http://www.mikroe.com/eng/products/view/852/easymx-pro-v7-for-stm32/
     Oscillator:      HS-PLL 72.0000 MHz
     ext. modules:    BI Hall Click
                      http://www.mikroe.com/click/bi-hall/
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/

 NOTES:
      - Place UNI Hall Click board in the mikroBUS socket 1.
      - Set development board J5 jumper according to SMD jumper on click board. By default it's soldered in the 3.3V position.
      - Turn On SW15-6 switches for PORTD LEDs.

*/

char cnt, old_cnt;

void ExtInt() iv IVT_INT_EXTI15_10 ics ICS_AUTO {
  EXTI_PR.B10 = 1;                     // clear flag
  cnt++;
}

void main() {
   GPIO_Digital_Output(&GPIOD_BASE, _GPIO_PINMASK_ALL);  // Enable digital output on PORTD
   GPIOD_ODR = 0;
   GPIO_Digital_Input(&GPIOD_BASE, _GPIO_PINMASK_10);               // Reset PortD
   cnt     = 0;
   old_cnt = cnt;

   RCC_APB2ENR.AFIOEN = 1;              // Enable clock for alternate pin functions
   AFIO_EXTICR3 = 0x0300;               // PD10 as External interrupt
   EXTI_RTSR = 0x00000400;              // Set interrupt on Rising edge
   EXTI_IMR |= 0x00000400;              // Set mask
   NVIC_IntEnable(IVT_INT_EXTI15_10);   // Enable External interrupt

   EnableInterrupts();                  // Enables the processor interrupt.

   while(1) {
      if (old_cnt != cnt) {
         GPIOD_ODR = cnt;
         old_cnt = cnt;
      }
   }
}